@@ -46,7 +46,6 @@ TOP_LEVEL_IGNORE = frozenset({
     "__module__",
     "__name__",
     "__annotations__",
-    "google_type_annotations",
 })
 CLASS_LEVEL_IGNORE = frozenset({
     "__builtins__",
@@ -787,3 +786,8 @@ def _make(cls_name, *args, **kwargs):
 
 def is_recursive_annotation(annot):
   return annot.is_late_annotation() and annot.is_recursive()
+
+
+def is_ellipsis(val):
+  return (val == val.ctx.convert.ellipsis or
+          (is_concrete(val) and val.pyval == "..."))
