@@ -7,13 +7,13 @@ from pytype import overlay
 class FutureUtilsOverlay(overlay.Overlay):
   """A custom overlay for the 'future' module."""
 
-  def __init__(self, vm):
+  def __init__(self, ctx):
     member_map = {
         "with_metaclass": build_with_metaclass,
     }
-    ast = vm.loader.import_name("future.utils")
-    super().__init__(vm, "future.utils", member_map, ast)
+    ast = ctx.loader.import_name("future.utils")
+    super().__init__(ctx, "future.utils", member_map, ast)
 
 
-def build_with_metaclass(vm):
-  return metaclass.WithMetaclass.make("with_metaclass", vm, "future.utils")
+def build_with_metaclass(ctx):
+  return metaclass.WithMetaclass.make("with_metaclass", ctx, "future.utils")
