@@ -107,7 +107,7 @@ class TypeMatch(pytd_utils.TypeMatcher):
         A list of pytd.Type.
     """
     if isinstance(t, pytd.ClassType):
-      return sum((self.get_superclasses(c) for c in t.cls.parents), [t])
+      return sum((self.get_superclasses(c) for c in t.cls.bases), [t])
     elif isinstance(t, pytd.AnythingType):
       # All types, even "?", inherit from object.
       return [pytd.NamedType("builtins.object")]
@@ -376,10 +376,9 @@ class TypeMatch(pytd_utils.TypeMatcher):
     Returns:
       An instance of booleq.BooleanTerm, i.e. a boolean formula.
     """
-    assert not sig1.template
     # Signatures have type parameters, too. We ignore them, since they can
     # be anything. (See maybe_lookup_type_param())
-    subst.update({p.type_param: None for p in sig2.template})
+    subst.update({p.type_param: None for p in sig1.template + sig2.template})
     params1 = sig1.params
     params2 = sig2.params
     if skip_self:
@@ -401,7 +400,7 @@ class TypeMatch(pytd_utils.TypeMatcher):
     # a kwonly on the left side means that it was a keyword param.
     for p1, p2 in zip(params1, params2):
       if p1.optional and not p2.optional:
-        return booleq.FALSE  # needed for optimize.py:RemoveRedundantSignatures
+        return booleq.FALSE
     for i, p2 in enumerate(params2):
       if i >= len(params1):
         if not p2.optional:
@@ -439,7 +438,7 @@ class TypeMatch(pytd_utils.TypeMatcher):
     if f1.name not in cls2_methods:
       # The class itself doesn't have this method, but base classes might.
       # TODO(b/159058933): This should do MRO order, not depth-first.
-      for base in cls2.parents:
+      for base in cls2.bases:
         if isinstance(base, pytd.AnythingType):
           # AnythingType can contain any method. However, that would mean that
           # a class that inherits from AnythingType contains any method
